@@ -28,7 +28,7 @@ def _parse_vocabulary(vocabulary):
     elif isinstance(vocabulary, str):
         return eval(vocabulary)
     else:
-        return []
+        return [i for i in vocabulary]
 
 
 def _get_categorical_column(params: dict) -> fc.CategoricalColumn:
@@ -298,12 +298,12 @@ class ParseFeatureConfig:
 def define_feature_json(key,
                         feature_type='NumericColumn',
                         feature_lenth=1,
-                        feature_dtype='float32',
-                        dimension=10,
-                        share_name='item',
-                        vocabulary='',
-                        bucket_size=16,
-                        num_buckets=16,
+                        feature_dtype=None,
+                        dimension=None,
+                        share_name=None,
+                        vocabulary=None,
+                        bucket_size=None,
+                        num_buckets=None,
                         *args, **kwargs):
     para = {
         "key": key,
@@ -316,6 +316,10 @@ def define_feature_json(key,
         "num_buckets": num_buckets
     }
     para.update(kwargs)
+    for key in para.keys():
+        if key is None or para[key] is None:
+            para.pop(key)
+    para = {k: v for k, v in para.items() if k is not None and v is not None}
 
     return {
         "type": feature_type,
